/*
  nokiaLCD.h - Library for providing a text based interface to the Nokia 5110 LCD screen
  Written by Rylee Isitt
  Parts of this Library are based on the example code provided by SparkFun, copyright 2011 Nathan Seidle
  SparkFun's code was used with permission (released into the public domain)
  I make no copyright claims to their original code
*/
#ifndef nokiaLCD_H
#define nokiaLCD_H

#include <Arduino.h>

// Configuration for the Nokia 5110 LCD
#define LCD_C     LOW
#define LCD_D     HIGH
#define LCD_X     84
#define LCD_Y     48
#define LCD_ROWS  6
#define LCD_COLS  14
#define LCD_CHAR_WIDTH  6
#define LCD_CHAR_HEIGHT  8

class nokiaLCD {
  public:
    nokiaLCD(void);
    ~nokiaLCD(void);
    void begin(byte pinSCE, byte pinRESET, byte pinDC, byte pinSDIN, byte pinSCLK, byte pinLED);
    void update(void);
    void writeLine(String text, boolean invert = false, boolean custom = false);
    void cls(void);
    void setRow(byte newRow);
    void setCol(byte newCol);
    void toggleBacklight(void);
    void setGlyphInvert(byte row, byte col, boolean invert);
    void setGlyphCustom(byte row, byte col, boolean custom);
  private:
    byte curText[LCD_ROWS][LCD_COLS];
    byte codes[LCD_ROWS][LCD_COLS];
    byte pinSCE;
    byte pinRESET;
    byte pinDC;
    byte pinSDIN;
    byte pinSCLK;
    byte pinLED;
    boolean backlightState;
    byte getGlyphByte(byte glyphID, byte glyphByteID, boolean useCustom = false);
    void lcdWrite(byte dc, byte data);
};

#endif